/*
 * OPEY 2008
 * Luokka puhelinluettelon kuvaamiseen.
 * Javassa on selvsti tehokkaampia rakenteita puhelinluettelon
 * toteuttamiseen kuin tss kytetetty ArrayList, mutta niit ei
 * ole opetettu tll kurssilla.
 * 
 * Kirjoittanut Kerttu Pollari-Malmi
 */
import java.util.ArrayList;

public class Puhelinluettelo {
  private ArrayList<Puhelintieto> rivit;
  private static final int NIMEA_EI_LOYDY = -1;


  /*
   * Konstruktori luo tyhjn puhelinluettelon.
   */
  public Puhelinluettelo() {
    this.rivit = new ArrayList<Puhelintieto>();
  }


  /*
   * Yksityinen apumetodi, joka hakee ja palauttaa parametrina annetun nimen
   * paikan puhelinluettelosta. 
   */
  private int haeNimenIndeksi(String haettavaNimi) {
    for (int i = 0; i < this.rivit.size(); i++)
      if (haettavaNimi.equals(this.rivit.get(i).kerroNimi()))
        return i;
    return NIMEA_EI_LOYDY;
  }


  /*
   * Metodi lis puhelinluetteloon uuden tietueen, jos tietueessa olevalla 
   * nimell ei jo ole numeroa luettelossa. Metodi palauttaa arvon
   * true, jos nimen lisays onnistui ja muuten arvon false.
   */
  public boolean lisaaRivi(Puhelintieto uusiRivi) {
    int paikka;

    paikka = this.haeNimenIndeksi(uusiRivi.kerroNimi());
    if (paikka == NIMEA_EI_LOYDY) {
      this.rivit.add(uusiRivi);
      return true;
    }
    else
      return false;
  }


  /*
   * Metodi etsii ja palauttaa parametrina annettua nime vastaavan
   * puhelinnumeron luettelosta. Jos nime ei lydy, metodi palauttaa
   * arvon null.
   */
  public String haeNumero(String annettuNimi) {
    int paikka;

    paikka = this.haeNimenIndeksi(annettuNimi);
    if (paikka == NIMEA_EI_LOYDY) 
      return null;
    else
      return this.rivit.get(paikka).kerroNumero();
  }


  /*
   * Metodi muuttaa ensimmisen parametrina annettua nime vastaavan 
   * puhelinnumeron luettelossa, jos nimi on luettelossa. Uusi 
   * puhelinnumero annetaan toisena parametrina. Jos muutos onnistuu, metodi
   * palauttaa arvon true. Jos nime ei lydy ja muutos ei siten
   * onnistu, metodi palauttaa arvon false.
   */
  public boolean vaihdaNumero(String annettuNimi, String uusiNumero) {
    int paikka;

    paikka = this.haeNimenIndeksi(annettuNimi);
    if (paikka == NIMEA_EI_LOYDY) 
      return false;
    else {
      this.rivit.get(paikka).muutaNumero(uusiNumero);
      return true;
    }
  }


  /*
   * Metodi palauttaa merkkijonon, joka sislt kaikki 
   * puhelinluettelon rivit;
   */
  public String toString() {
    String mjono = "";
    for (int i = 0; i < this.rivit.size(); i++)
      mjono += this.rivit.get(i) + "\n";
    return mjono;
  }    
}
